==> commons-configuration_1.4.orig.tar.gz: commons-configuration-1.4-src/src/test/org/apache/commons/configuration/beanutils/TestConfigurationDynaBeanXMLConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.configuration.beanutils;

import org.apache.commons.configuration.Configuration;
import org.apache.commons.configuration.XMLConfiguration;

/**
 * An additional test class for ConfigurationDynaBean. This test class performs
 * the same tests as the default test class, but uses a XMLConfiguration as
 * underlying configuration object.
 *
 * @author <a
 * href="http://jakarta.apache.org/commons/configuration/team-list.html">Commons
 * Configuration team</a>
 * @version $Id: TestConfigurationDynaBeanXMLConfig.java 469259 2006-10-30 20:22:50Z oheger $
 */
public class TestConfigurationDynaBeanXMLConfig extends
        TestConfigurationDynaBean
{
    /**
     * Creates the underlying configuration object. This implementation will
     * create a XMLConfiguration.
     * @return the underlying configuration
     */
    protected Configuration createConfiguration()
    {
        return new XMLConfiguration();
    }
}

==> commons-configuration_1.6.orig.tar.gz: commons-configuration-1.6-src/src/test/org/apache/commons/configuration/beanutils/TestConfigurationDynaBeanXMLConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.configuration.beanutils;

import org.apache.commons.configuration.Configuration;
import org.apache.commons.configuration.XMLConfiguration;

/**
 * An additional test class for ConfigurationDynaBean. This test class performs
 * the same tests as the default test class, but uses a XMLConfiguration as
 * underlying configuration object.
 *
 * @author <a
 * href="http://commons.apache.org/configuration/team-list.html">Commons
 * Configuration team</a>
 * @version $Id: TestConfigurationDynaBeanXMLConfig.java 561230 2007-07-31 04:17:09Z rahul $
 */
public class TestConfigurationDynaBeanXMLConfig extends
        TestConfigurationDynaBean
{
    /**
     * Creates the underlying configuration object. This implementation will
     * create a XMLConfiguration.
     * @return the underlying configuration
     */
    protected Configuration createConfiguration()
    {
        return new XMLConfiguration();
    }
}
